{
    'name': 'Graph Views',
    'category': 'Hidden',
    'description': """
Graph Views for Web Client.
===========================

    * Parse a <graph> view but allows changing dynamically the presentation
    * Graph Types: pie, lines, areas, bars, radar
    * Stacked/Not Stacked for areas and bars
    * Legends: top, inside (top/left), hidden
    * Features: download as PNG or CSV, browse data grid, switch orientation
    * Unlimited "Group By" levels (not stacked), two cross level analysis (stacked)
""",
    'version': '3.0',
    'depends': ['web'],
    'js': [
        'static/lib/dropdown.js',
        'static/lib/flotr2/lib/bean.js',
        'static/lib/flotr2/js/Flotr.js',
        'static/lib/flotr2/js/DefaultOptions.js',
        'static/lib/flotr2/js/Color.js',
        'static/lib/flotr2/js/Date.js',
        'static/lib/flotr2/js/DOM.js',
        'static/lib/flotr2/js/EventAdapter.js',
        'static/lib/flotr2/js/Text.js',
        'static/lib/flotr2/js/Graph.js',
        'static/lib/flotr2/js/Axis.js',
        'static/lib/flotr2/js/Series.js',
        'static/lib/flotr2/js/types/lines.js',
        'static/lib/flotr2/js/types/bars.js',
        'static/lib/flotr2/js/types/bubbles.js',
        'static/lib/flotr2/js/types/candles.js',
        'static/lib/flotr2/js/types/gantt.js',
        'static/lib/flotr2/js/types/markers.js',
        'static/lib/flotr2/js/types/pie.js',
        'static/lib/flotr2/js/types/points.js',
        'static/lib/flotr2/js/types/radar.js',
        'static/lib/flotr2/js/types/timeline.js',
        'static/lib/flotr2/js/plugins/crosshair.js',
        'static/lib/flotr2/js/plugins/download.js',
        'static/lib/flotr2/js/plugins/grid.js',
        'static/lib/flotr2/js/plugins/hit.js',
        'static/lib/flotr2/js/plugins/selection.js',
        'static/lib/flotr2/js/plugins/labels.js',
        'static/lib/flotr2/js/plugins/legend.js',
        'static/lib/flotr2/js/plugins/spreadsheet.js',
        'static/lib/flotr2/js/plugins/titles.js',
        'static/src/js/graph.js'
    ],
    'css': [
        'static/src/css/*.css',
    ],
    'qweb' : [
        'static/src/xml/*.xml',
    ],
    'auto_install': True
}



#! /usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Replacement (unofficial) `setup.py` for the `web_graph` module.
Automatically generated by `openerpdist`. See http://noteed.com/openerpdist/.
"""

import setuptools

setuptools.setup(
    name = "openerp-web-graph",
    version = "7.0.406",
    description = "Graph Views",
    long_description = 
"""

Graph Views for Web Client.
===========================

    * Parse a <graph> view but allows changing dynamically the presentation
    * Graph Types: pie, lines, areas, bars, radar
    * Stacked/Not Stacked for areas and bars
    * Legends: top, inside (top/left), hidden
    * Features: download as PNG or CSV, browse data grid, switch orientation
    * Unlimited "Group By" levels (not stacked), two cross level analysis (stacked)
""",
    url = "",
    author = "",
    author_email = "TODO",
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Environment :: Plugins",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Natural Language :: English",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    license = "AGPL-3",
    package_dir = {
        'openerp.addons.web_graph': ".",
    },
    packages = ["openerp.addons.web_graph"],
    package_data = {
        'openerp.addons.web_graph': ["i18n/*.po*","static/lib/dropdown.js","static/lib/flotr2/flotr2.min.js","static/lib/flotr2/flotr2.examples.types.js","static/lib/flotr2/flotr2.ie.min.js","static/lib/flotr2/flotr2.examples.min.js","static/lib/flotr2/flotr2.js","static/lib/flotr2/lib/bean-min.js","static/lib/flotr2/lib/canvastext.js","static/lib/flotr2/lib/underscore.js","static/lib/flotr2/lib/excanvas.js","static/lib/flotr2/lib/prototype.js","static/lib/flotr2/lib/yepnope.js","static/lib/flotr2/lib/imagediff.js","static/lib/flotr2/lib/canvas2image.js","static/lib/flotr2/lib/underscore-min.js","static/lib/flotr2/lib/bean.js","static/lib/flotr2/lib/base64.js","static/lib/flotr2/lib/jasmine/jasmine_favicon.png","static/lib/flotr2/lib/jasmine/jasmine-html.js","static/lib/flotr2/lib/jasmine/jasmine.js","static/lib/flotr2/js/DOM.js","static/lib/flotr2/js/Date.js","static/lib/flotr2/js/Graph.js","static/lib/flotr2/js/EventAdapter.js","static/lib/flotr2/js/Flotr.js","static/lib/flotr2/js/Text.js","static/lib/flotr2/js/Color.js","static/lib/flotr2/js/Series.js","static/lib/flotr2/js/Axis.js","static/lib/flotr2/js/DefaultOptions.js","static/lib/flotr2/js/plugins/grid.js","static/lib/flotr2/js/plugins/selection.js","static/lib/flotr2/js/plugins/hit.js","static/lib/flotr2/js/plugins/handles.js","static/lib/flotr2/js/plugins/crosshair.js","static/lib/flotr2/js/plugins/labels.js","static/lib/flotr2/js/plugins/legend.js","static/lib/flotr2/js/plugins/titles.js","static/lib/flotr2/js/plugins/download.js","static/lib/flotr2/js/plugins/spreadsheet.js","static/lib/flotr2/js/types/timeline.js","static/lib/flotr2/js/types/gantt.js","static/lib/flotr2/js/types/markers.js","static/lib/flotr2/js/types/candles.js","static/lib/flotr2/js/types/bars.js","static/lib/flotr2/js/types/pie.js","static/lib/flotr2/js/types/lines.js","static/lib/flotr2/js/types/points.js","static/lib/flotr2/js/types/bubbles.js","static/lib/flotr2/js/types/radar.js","static/src/xml/web_graph.xml","static/src/js/graph.js","i18n/fa.po","i18n/hr.po","i18n/da.po","i18n/sl.po","i18n/es_MX.po","i18n/fr_CA.po","i18n/ru.po","i18n/en_GB.po","i18n/cs.po","i18n/sq.po","i18n/fi.po","i18n/bn.po","i18n/pt_BR.po","i18n/ko.po","i18n/gu.po","i18n/bg.po","i18n/ja.po","i18n/ro.po","i18n/sr@latin.po","i18n/es.po","i18n/ka.po","i18n/mn.po","i18n/es_CL.po","i18n/it.po","i18n/nl.po","i18n/sv.po","i18n/es_EC.po","i18n/bs.po","i18n/tr.po","i18n/en_AU.po","i18n/de.po","i18n/et.po","i18n/lt.po","i18n/hu.po","i18n/gl.po","i18n/mk.po","i18n/ca.po","i18n/fr.po","i18n/zh_CN.po","i18n/pl.po","i18n/he.po","i18n/th.po","i18n/nl_BE.po","i18n/es_DO.po","i18n/nb.po","i18n/ar.po","i18n/pt.po","i18n/es_CR.po","static/src/xml/*.xml","static/src/css/*.css","static/lib/dropdown.js","static/lib/flotr2/lib/bean.js","static/lib/flotr2/js/Flotr.js","static/lib/flotr2/js/DefaultOptions.js","static/lib/flotr2/js/Color.js","static/lib/flotr2/js/Date.js","static/lib/flotr2/js/DOM.js","static/lib/flotr2/js/EventAdapter.js","static/lib/flotr2/js/Text.js","static/lib/flotr2/js/Graph.js","static/lib/flotr2/js/Axis.js","static/lib/flotr2/js/Series.js","static/lib/flotr2/js/types/lines.js","static/lib/flotr2/js/types/bars.js","static/lib/flotr2/js/types/bubbles.js","static/lib/flotr2/js/types/candles.js","static/lib/flotr2/js/types/gantt.js","static/lib/flotr2/js/types/markers.js","static/lib/flotr2/js/types/pie.js","static/lib/flotr2/js/types/points.js","static/lib/flotr2/js/types/radar.js","static/lib/flotr2/js/types/timeline.js","static/lib/flotr2/js/plugins/crosshair.js","static/lib/flotr2/js/plugins/download.js","static/lib/flotr2/js/plugins/grid.js","static/lib/flotr2/js/plugins/hit.js","static/lib/flotr2/js/plugins/selection.js","static/lib/flotr2/js/plugins/labels.js","static/lib/flotr2/js/plugins/legend.js","static/lib/flotr2/js/plugins/spreadsheet.js","static/lib/flotr2/js/plugins/titles.js","static/src/js/graph.js"],
    },
    install_requires = ["openerp-web"],
    tests_require = ["unittest2"],
)
